Name:           gerbera
Version:        1.6.4
Release:        %mkrel 3
Summary:        UPnP Media Server
License:        GPLv2 and MIT and OFL
Group:          System/Servers
Url:            https://gerbera.io
Source0:        https://github.com/gerbera/gerbera/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        config.xml

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  libupnp-devel
BuildRequires:  libuuid-devel
BuildRequires:  expat-devel
BuildRequires:  libffmpegthumbnailer-devel
BuildRequires:  sqlite3-devel
BuildRequires:  duktape-devel
BuildRequires:  curl-devel
BuildRequires:  taglib-devel
BuildRequires:  file-devel
BuildRequires:  libexif-devel
BuildRequires:  exiv2-devel
BuildRequires:  cmake
BuildRequires:  zlib-devel
BuildRequires:  libebml-devel
BuildRequires:  libmatroska-devel
BuildRequires:  fmt-devel
BuildRequires:  systemd-devel
BuildRequires:  spdlog-devel
BuildRequires:  pugixml-devel
BuildRequires:  ffmpeg-devel

%{?systemd_requires}
Requires:       %{name}-data = %{version}-%{release}
Obsoletes:      mediatomb < 0.12.1-26

%description
Gerbera is a UPnP media server which allows you to stream your digital
media through your home network and consume it on a variety of UPnP
compatible devices.

%package data
Summary:        Data files for Gerbera
BuildArch:      noarch

%description data
Data files for the Gerbera media server.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%cmake \
    -DWITH_JS:BOOL=YES \
    -DWITH_MYSQL:BOOL=NO \
    -DWITH_CURL:BOOL=YES \
    -DWITH_TAGLIB:BOOL=YES \
    -DWITH_MAGIC:BOOL=YES \
    -DWITH_AVCODEC:BOOL=YES \
    -DWITH_EXIF:BOOL=YES \
    -DWITH_EXIV2:BOOL=YES \
    -DWITH_FFMPEGTHUMBNAILER:BOOL=YES \
    -DWITH_INOTIFY:BOOL=YES \
    -DWITH_SYSTEMD:BOOL=YES \
    -DUPNP_HAS_REUSEADDR:BOOL=YES
%cmake_build

%install
install -p -D -m0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/gerbera/config.xml
%cmake_install

# make all files under %%_sysconfdir/gerbera owned by
# this package
mkdir -p %{buildroot}%{_sysconfdir}/gerbera
touch %{buildroot}%{_sysconfdir}/gerbera/{gerbera.db,gerbera.html}
mkdir -p %{buildroot}%{_localstatedir}/log/gerbera
touch %{buildroot}%{_localstatedir}/log/%{name}
mkdir -p  %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/%{name} << 'EOF'
%{_logdir}/gerbera/gerbera {
create 644 gerbera gerbera
      monthly
      compress
      missingok
}
EOF

%pre
%_pre_useradd %{name} %{_sysconfdir}/gerbera %{_sbindir}/nologin

%post
%systemd_post gerbera.service

%preun
%systemd_preun gerbera.service

%postun
%systemd_postun_with_restart gerbera.service

%files
%license LICENSE.md
%doc AUTHORS CONTRIBUTING.md ChangeLog.md
%attr(-,gerbera,gerbera) %dir %{_sysconfdir}/%{name}/
%attr(-,gerbera,gerbera) %config(noreplace) %{_sysconfdir}/%{name}/*
%attr(-,gerbera,gerbera) %{_localstatedir}/log/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sysconfdir}/logrotate.d/
%{_bindir}/%{name}
%{_mandir}/man1/*
%{_unitdir}/gerbera.service

%files data
%dir %{_datadir}/gerbera/
%{_datadir}/gerbera/mappings.xml
%{_datadir}/gerbera/mysql.sql
%{_datadir}/gerbera/sqlite3.sql
%dir %{_datadir}/gerbera/js/
%config(noreplace) %{_datadir}/gerbera/js/import_structured.js
%config(noreplace) %{_datadir}/gerbera/js/import.js
%config(noreplace) %{_datadir}/gerbera/js/playlists.js
%config(noreplace) %{_datadir}/gerbera/js/common.js
%{_datadir}/gerbera/web/


%changelog
* Fri Dec 04 2020 luigiwalser <luigiwalser> 1.6.4-3.mga8
+ Revision: 1652440
- rebuild for libupnp

* Tue Nov 17 2020 wally <wally> 1.6.4-2.mga8
+ Revision: 1646910
- rebuild for new duktape 2.6.0

* Sat Oct 17 2020 wally <wally> 1.6.4-1.mga8
+ Revision: 1636529
- new version 1.6.4

* Thu Oct 15 2020 wally <wally> 1.6.1-2.mga8
+ Revision: 1636270
- fix user creation in %%pre (mga#27425)
- build with avcodec

* Mon Oct 12 2020 wally <wally> 1.6.1-1.mga8
+ Revision: 1634581
- new version 1.6.1

* Sat Aug 22 2020 wally <wally> 1.6.0-1.mga8
+ Revision: 1617977
- new version 1.6.0

* Wed Jul 22 2020 zezinho <zezinho> 1.5.0-2.mga8
+ Revision: 1607849
- rebuild against new libebml5

* Sun May 24 2020 wally <wally> 1.5.0-1.mga8
+ Revision: 1587304
- import based on .spec from Fedora
- obsolete mediatomb

